"""Configuration needed for autogeneration of HLT functors"""
from Gaudi.Configuration import DEBUG, appendPostConfigAction


def post_action_for_cpp():
    # When running from TCK, the factories need to be told like this to
    # generate CPP
    from Moore import Funcs
    outputTrans = {".*Factory.*": {"MakeCpp": {"^.*$": "True"},
                                   "UseCache": {"^.*$": "False"}}}
    Funcs._mergeTransform(outputTrans)

    from Gaudi.Configuration import log
    from Configurables import ApplicationMgr
    app = ApplicationMgr()
    app.EvtMax = 0
    app.EvtSel = 'NONE'
    # get rid of warnings that no events will be processed, doh!
    from Configurables import EventLoopMgr
    EventLoopMgr().Warnings = False

    from Configurables import LHCb__ParticlePropertySvc as PPSvc
    from Configurables import DetDataSvc
    from Configurables import LoKiSvc

    # some reshuffling of order of services is needed
    app.ExtSvc = [DetDataSvc('DetectorDataSvc'), PPSvc(),
                  LoKiSvc(Welcome=False)] + app.ExtSvc

    # suppress printout of various summaries from algorithms.
    from Gaudi.Configuration import allConfigurables
    for conf in allConfigurables.itervalues():
        for opt in ('StatPrint', 'ErrorsPrint', 'HistoPrint'):
            if opt in conf.__slots__:
                setattr(conf, opt, False)

    # ensure that prints from the main tools/factories are not suppressed
    from Configurables import LoKi__Hybrid__CoreFactory as CoreFactory
    from Configurables import LoKi__Hybrid__Tool as HybridFactory
    from Configurables import LoKi__Hybrid__HltFactory as HltFactory

    for conf in allConfigurables.itervalues():
        if isinstance(conf, (HltFactory, CoreFactory, HybridFactory)):
            conf.OutputLevel = DEBUG
            conf.StatPrint = True


# Post-config action inception follows!
#
# Moore is particularly stubborn and overrides the OutputLevel of almost
# everything if Moore().OutputLevel > INFO. To overcome this, we have to
# append our post-config action after Moore adds theirs. Therefore, we
# add a post-config action that appends the real post-config action!
# This relies on the way actions are invoked in GaudiKernel.Configurable.
appendPostConfigAction(lambda: appendPostConfigAction(post_action_for_cpp))
