import csv
import difflib
import re
import subprocess
from tempfile import NamedTemporaryFile


def read_csv(filename):
    with open(filename, 'r') as f:
        reader = csv.reader(f, skipinitialspace=True)
        header = next(reader)
        return [dict(zip(header, row)) for row in reader]

def add_ancestors(table):
    ancestors = [None]*100
    new_table = []
    for row in table:
        depth = len(row['Depth']) - 1
        ancestors[depth] = row['Algorithm']
        d = row.copy()
        d['Ancestors'] = ancestors[:(depth + 1)]
        new_table.append(d)
    return new_table


def format_diff_table(table):
    return ['{entries:5} {Depth} {Algorithm}\n'.format(**line) for line in table]


def filter_ancestor(table, ancestor):
    table = add_ancestors(table)
    return [row for row in table if ancestor in row['Ancestors']]


def censor_algs(table, pattern, remove=False):
    new_table = []
    for row in table:
        new_row = row.copy()
        if re.match(pattern, row['Algorithm']):
            if not remove:
                new_row['entries'] = ''
                new_table.append(new_row)
        else:
            new_table.append(new_row)
    return new_table


def system_diff(lines1, lines2, args=[]):
    with NamedTemporaryFile() as f1:
        f1.writelines(lines1)
        with NamedTemporaryFile() as f2:
            f2.writelines(lines2)
            try:
                return subprocess.check_output(['diff'] + args + [f1.name, f2.name])
            except subprocess.CalledProcessError as e:
                if e.returncode == 1:
                    return e.output
                raise


def ndiff(lines1, lines2, name1='', name2=''):
    if lines1 == lines2:
        return []
    diff = list(difflib.ndiff(lines1, lines2))
    s = '--- {}\n+++ {}\n'.format(name1, name2) + ''.join(diff)
    return s
