import os
import re
import argparse
from TCKUtils.utils import *


def is_hex(s):
    try:
        int(s, 16)
        return True
    except ValueError:
        return False


def id_from_log(filename):
    pattern = '^HltGenConfig +INFO + top id for this config: ([0-9a-f]{32})$'
    with open(filename) as f:
        for line in f:
            m = re.match(pattern, line)
            if m:
                return m.group(1)
    raise RuntimeError('File {} does not look like TCK creation output!'.format(filename))


def settings_from_options(filename):
    g = {}
    execfile(filename, g)
    # a hack to remove any configurable instances coming from the options file
    from GaudiKernel.Configurable import Configurable
    Configurable.allConfigurables = {}
    return g['settings']


parser = argparse.ArgumentParser()
parser.add_argument("id", help='Top level configuration id or TCK creation log.')
parser.add_argument("tck", help='TCK (e.g. 0x12345678) or key in options (e.g. Hlt1TCK).')
parser.add_argument("--tckdata", default='TCKData', help='Directory containing the config.cdb file.')
parser.add_argument("--options", help='Options where Hlt1TCK/Hlt2TCK and TCKData are defined.')
args = parser.parse_args()


if not (len(args.id) == 32 and is_hex(args.id)):
    # we might be given a filename
    args.id = id_from_log(args.id)


if not is_hex(args.tck):
    if not args.options:
        parser.error('--options is required when TCK is not given directly')
    settings = settings_from_options(args.options)
    args.tck = settings[args.tck]
    args.tckdata = settings['TCKData']

configdb = os.path.join(os.path.expandvars(args.tckdata), 'config.cdb')
cas_rw = ConfigAccessSvc(Mode='ReadWrite', File=configdb)
createTCKEntries({args.tck: args.id}, cas=cas_rw)
