import argparse
from TCKUtils.utils import *
from TCKUtils.utils import _sortReleases

EXCLUSIONS = [
#     r'.*\.ExtraInputs$',
#     r'.*\.IsClonable$',
#     r'.*\.RootOnTES$',
#     r'.*\.Cardinality$',
#     r'.*\.IsIOBound$',
#     r'.*\.GlobalTimeOffset$',
#     r'.*\.NeededResources$',
#     r'.*\.ExtraOutputs$',
#     r'.*\.ErrorCounter$',
#     r'.*\.AuditReinitialize$',
#     r'.*\.AuditRestart$',
#     r'.*\.Timeline$',
#     r'.*\.XRegions$',
#     r'.*\.Sequential$',
#     r'.*\.Invert$',
#     r'.*\.reverseVeloCharge$',
#     r'.*\.StatPrint$',
#     r'.*\.ErrorsPrint$',
]

def get_tcks(split='', hlttype='.*', cas=default_cas):
    def tck_ok(tck):
        f = tck_flags(tck)
        return f['Split'] == split and not f['MC'] and not f['Technical']

    # Flatten potenitally multiple TCKs per configuration
    configs = [(config.info, tck)
               for config in getConfigurations(cas=cas).values()
               for tck in config.info['TCK']]
    # Filter by split and hlttype and obtain a list of (release, tck)
    configs = [(_sortReleases(info['release']), tck_to_int(tck))
               for info, tck in configs
               if tck_ok(tck) and re.match(hlttype, info['hlttype'])]
    configs.sort(reverse=True)
    return [tck for release, tck in configs]


parser = argparse.ArgumentParser()
parser.add_argument('--split', help='split level (Hlt1 or Hlt2).')
parser.add_argument('--tck', help='existing tck (default is "latest")')
parser.add_argument('--hlttype', default=r'^Physics_pp.*', help='HltType regex')
args = parser.parse_args()

cas = ConfigAccessSvc('CustomCAS', File='TCKData/config.cdb')
stack_cas = ConfigStackAccessSvc(ConfigAccessSvcs=[cas, default_cas])

tcks = get_tcks(args.split, args.hlttype, cas=cas)
print 'found the following {} TCKs: {}'.format(
    args.split, map(tck_to_str, tcks))

if args.tck:
    old_tck = tck_to_int(args.tck)
else:
    old_tck = get_tcks(args.split, args.hlttype)[0]
    print 'found last existing tck:', tck_to_str(old_tck)

diff(old_tck, tcks[0], human=True, exclusions=EXCLUSIONS, cas=stack_cas)
