from __future__ import print_function
import re
import sys
import argparse
from TCKUtils.utils import *


def int16(x):
    return int(x, 16)


def re_match_iter(iterable, pattern):
    return list(filter(re.compile(pattern).match, iterable))


parser = argparse.ArgumentParser()
parser.add_argument("tck1", type=int16, help='Hlt1 TCK')
parser.add_argument("tck2", type=int16, help='Hlt2 TCK')
parser.add_argument("--cas", help='Path to config.cdb')
args = parser.parse_args()

cas = ConfigAccessSvc(File=args.cas) if args.cas else default_cas


lines1 = getHlt1Lines(args.tck1, cas=cas)

# Each entry is a tuple of (<set of sibling lines>, <exception regex>)
# Lines matching the regex will not trigger a failure.
sibling_lines = []

# Find all Loose/Tight lines and the corresponding nominal lines
pattern = r'Loose|Tight'
for line in lines1:
    if re.search(pattern, line):
        nominal = re.sub(pattern, '', line)
        if nominal in lines1:
            sibling_lines.append((set([line, nominal]), None))

if 'Hlt1TrackMVA' in lines1 and 'Hlt1TrackAllL0' in lines1:
    sibling_lines.append(({'Hlt1TrackMVA', 'Hlt1TrackAllL0'}, None))

# Make sure Hlt1TrackMuon and Hlt1TrackMuonMVA are accepted together
matches = re_match_iter(lines1, r'Hlt1TrackMuon(MVA)?')
sibling_lines.append((
    set(matches),
    r'^Hlt2RareStrangeKsPiPiEETOS|Hlt2TrackEffElectronDetachedMu.*$'))

# TODO the checks here should probably go only one way, i.e. for example
#      any line that accepts TrackMVA should accept TrackMVATight but
#      not TrackMVALoose. Similarly, Hlt1TrackMuon should imply
#      Hlt1TrackMuonMVA but not the other way arround.

fail = False
# Check that every Hlt2 line accepts either none or all sibling lines
for line in sorted(getHlt2Lines(args.tck2, cas=cas)):
    print('Checking {}...'.format(line))
    inputs = getHltLineInputs(args.tck2, line, args.tck1, cas=cas)
    if 'HLT1' not in inputs:
        continue
    for sl, exception in sibling_lines:
        accepted = sl & set(inputs['HLT1'])
        if len(accepted) != 0 and len(accepted) != len(sl):
            if exception and re.match(exception, line):
                print('WARNING: {} accepts only {} (exception)'
                      .format(line, list(accepted)))
                continue
            print('ERROR: {} should accept either none or all of {}!'
                  .format(line, list(sl)))
            print('It currently accepts only {}'.format(list(accepted)))
            fail = True

if fail:
    sys.exit(1)
