'''Options to profile the python configuration in gaudirun.py

Add this to the beginning or end of your list of options, e.g.:
$ gaudirun.py options.py profile-config.py

To use the .pstats dump do:
$ gprof2dot -f pstats profile.pstats | dot -Tpng -o profile.png
$ gprof2dot -f pstats `ls -t *.pstats | head -1` | dot -Tsvg -o profile.png

For this to work, the following dependencies are needed:
$ pip install gprof2dot
$ yum install graphviz
'''

import cProfile
import pstats
import StringIO
import sys
import os
from datetime import datetime
from Gaudi.Configuration import appendPostConfigAction

profile = cProfile.Profile()

filename = ('profile-{:%Y%m%dT%H%M}-{}.pstats'
            .format(datetime.now(), os.getpid()))

def start_profile():
    profile.enable()

def stop_profile(sortby='cumulative'):
    profile.disable()
    s = StringIO.StringIO()
    ps = pstats.Stats(profile, stream=s).sort_stats(sortby)
    ps.dump_stats(filename)
    ps.print_stats(.1)
    sys.stderr.write(s.getvalue())

# Post-config action inception, or how do we make sure this is really
# the last thing to be called
appendPostConfigAction(lambda: appendPostConfigAction(stop_profile))

start_profile()
